// 	$Id: BoolNetObserverSwarm.h,v 1.3 1998/02/27 22:01:10 mgd Exp $	
#import <objectbase.h>
#import <activity.h>
#import <collections.h>
#import <analysis.h>
#import <simtoolsgui/GUISwarm.h>
#import "BoolNetModelSwarm.h"

@interface BoolNetObserverSwarm: GUISwarm
{
  int displayFrequency;
  int interactiveGraph;
  id displayActions;	
  id displaySchedule;

  BoolNetModelSwarm * boolNetModelSwarm;

  id graphCanvas ;

  // no graphs, yet
  //   BLTGraph * investorGraph;			  
  //   GraphElement * investorData;			  
  //   Entropy * investorEntropy;   		  
  //   ActiveGraph * investorGrapher;		  
  //   GraphElement * borrowerData;			  
  //   Entropy * borrowerEntropy;   		  
  //   ActiveGraph * borrowerGrapher;		  
  id activeBoolNets ;
  
}

+createBegin: (id) aZone;
-createEnd;
-buildObjects;
-buildActions;
-activateIn: (id) swarmContext;

// -redistribute ;  leave out at the moment

@end
